@@ -1,14 +1,16 @@
 package Config::IOD;
 
-our $DATE = '2021-06-23'; # DATE
-our $VERSION = '0.352'; # VERSION
-
 use 5.010001;
 use strict;
 use warnings;
 
 use parent qw(Config::IOD::Base);
 
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2022-05-02'; # DATE
+our $DIST = 'Config-IOD'; # DIST
+our $VERSION = '0.353'; # VERSION
+
 sub _init_read {
     my $self = shift;
 
@@ -155,6 +157,11 @@ sub _read_string {
                 $5, # COL_K_VALUE_RAW
                 $6, # COL_K_NL
             ];
+
+            if ($self->{warn_perl} && !$4 && substr($5, 0, 1) eq '>') {
+                $self->_warn("Probably using Perl syntax instead of INI: $line");
+            }
+
             if (!$self->{allow_duplicate_key}) {
                 my $kmem = $self->{_key_mem};
                 if ($kmem->{$self->{_cur_section}}{$2}) {
@@ -194,7 +201,7 @@ Config::IOD - Read and write IOD/INI configuration files
 
 =head1 VERSION
 
-This document describes version 0.352 of Config::IOD (from Perl distribution Config-IOD), released on 2021-06-23.
+This document describes version 0.353 of Config::IOD (from Perl distribution Config-IOD), released on 2022-05-02.
 
 =head1 SYNOPSIS
 
@@ -239,12 +246,6 @@ keys, etc) are also provided.
 If you only need to read IOD configuration files, you might want to use
 L<Config::IOD::Reader> instead.
 
-=head1 CONTRIBUTOR
-
-=for stopwords Steven Haryanto
-
-Steven Haryanto <sharyanto@cpan.org>
-
 =head1 ATTRIBUTES
 
 =head2 default_section => str (default: C<GLOBAL>)
@@ -404,6 +405,15 @@ simply be ignored as a regular comment.
 
 B<NOTE: Turning this setting on violates IOD specification.>
 
+=head2 warn_perl => bool (default: 0)
+
+Emit warning if configuration contains key line like these:
+
+ foo=>"bar"
+ foo => bar,
+
+which suggest user is assuming configuration is in Perl format instead of INI.
+
 =head1 METHODS
 
 =head2 new(%attrs) => obj
@@ -426,14 +436,6 @@ Please visit the project's homepage at L<https://metacpan.org/release/Config-IOD
 
 Source repository is at L<https://github.com/perlancar/perl-Config-IOD>.
 
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Config-IOD>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
 =head1 SEE ALSO
 
 L<IOD> - specification
@@ -448,11 +450,42 @@ L<IOD::Examples> - sample documents
 
 perlancar <perlancar@cpan.org>
 
+=head1 CONTRIBUTOR
+
+=for stopwords Steven Haryanto
+
+Steven Haryanto <stevenharyanto@gmail.com>
+
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
+beyond that are considered a bug and can be reported to me.
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021, 2019, 2017, 2016, 2015, 2011 by perlancar@cpan.org.
+This software is copyright (c) 2022, 2021, 2019, 2017, 2016, 2015, 2011 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Config-IOD>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =cut
