@@ -1,8 +1,5 @@
 package Config::IOD::Document;
 
-our $DATE = '2021-06-23'; # DATE
-our $VERSION = '0.352'; # VERSION
-
 use 5.010;
 use strict;
 use warnings;
@@ -10,6 +7,11 @@ use warnings;
 
 use Config::IOD::Constants qw(:ALL);
 
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2022-05-02'; # DATE
+our $DIST = 'Config-IOD'; # DIST
+our $VERSION = '0.353'; # VERSION
+
 sub new {
     my ($class, %attrs) = @_;
 
@@ -313,7 +315,7 @@ sub _find_section {
         return $linum unless $opts->{all};
         push @res, $linum;
     }
-    return undef unless $opts->{all};
+    return undef unless $opts->{all}; ## no critic: Subroutines::ProhibitExplicitReturnUndef
     return @res;
 }
 
@@ -452,7 +454,7 @@ sub _find_key {
         return $linum unless $opts->{all};
         push @res, $linum;
     }
-    return undef unless $opts->{all};
+    return undef unless $opts->{all}; ## no critic: Subroutines::ProhibitExplicitReturnUndef
     return @res;
 }
 
@@ -503,7 +505,7 @@ sub insert_section {
 
     if ($self->_find_section($name)) {
         if ($opts->{ignore}) {
-            return undef;
+            return undef; ## no critic: Subroutines::ProhibitExplicitReturnUndef
         } else {
             die "Can't insert section '$name': already exists";
         }
@@ -577,7 +579,7 @@ sub insert_key {
         $linum = $self->_find_key($section, $name);
         if ($linum) {
             if ($opts->{ignore}) {
-                return undef;
+                return undef; ## no critic: Subroutines::ProhibitExplicitReturnUndef
             } elsif ($opts->{add}) {
                 #
             } elsif ($opts->{replace}) {
@@ -821,7 +823,7 @@ Config::IOD::Document - Represent IOD document
 
 =head1 VERSION
 
-This document describes version 0.352 of Config::IOD::Document (from Perl distribution Config-IOD), released on 2021-06-23.
+This document describes version 0.353 of Config::IOD::Document (from Perl distribution Config-IOD), released on 2022-05-02.
 
 =head1 SYNOPSIS
 
@@ -1192,14 +1194,6 @@ Please visit the project's homepage at L<https://metacpan.org/release/Config-IOD
 
 Source repository is at L<https://github.com/perlancar/perl-Config-IOD>.
 
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Config-IOD>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
 =head1 SEE ALSO
 
 L<Config::IOD>
@@ -1208,11 +1202,36 @@ L<Config::IOD>
 
 perlancar <perlancar@cpan.org>
 
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
+beyond that are considered a bug and can be reported to me.
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021, 2019, 2017, 2016, 2015, 2011 by perlancar@cpan.org.
+This software is copyright (c) 2022, 2021, 2019, 2017, 2016, 2015, 2011 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Config-IOD>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =cut
