@@ -1,8 +1,5 @@
 package Test::Config::IOD;
 
-our $DATE = '2021-06-23'; # DATE
-our $VERSION = '0.352'; # VERSION
-
 ## no critic (Modules::ProhibitAutomaticExportation)
 
 use 5.010;
@@ -15,6 +12,12 @@ use Test::More;
 use Config::IOD;
 
 use Exporter qw(import);
+
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2022-05-02'; # DATE
+our $DIST = 'Config-IOD'; # DIST
+our $VERSION = '0.353'; # VERSION
+
 our @EXPORT = qw(test_modify_doc);
 
 sub test_modify_doc {
@@ -56,7 +59,7 @@ Test::Config::IOD - Testing routines for Config::IOD
 
 =head1 VERSION
 
-This document describes version 0.352 of Test::Config::IOD (from Perl distribution Config-IOD), released on 2021-06-23.
+This document describes version 0.353 of Test::Config::IOD (from Perl distribution Config-IOD), released on 2022-05-02.
 
 =head1 FUNCTIONS
 
@@ -74,6 +77,34 @@ Please visit the project's homepage at L<https://metacpan.org/release/Config-IOD
 
 Source repository is at L<https://github.com/perlancar/perl-Config-IOD>.
 
+=head1 AUTHOR
+
+perlancar <perlancar@cpan.org>
+
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
+beyond that are considered a bug and can be reported to me.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2022, 2021, 2019, 2017, 2016, 2015, 2011 by perlancar <perlancar@cpan.org>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Config-IOD>
@@ -82,15 +113,4 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
-=head1 AUTHOR
-
-perlancar <perlancar@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2021, 2019, 2017, 2016, 2015, 2011 by perlancar@cpan.org.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
